==> zio-aws-databasemigration_2.12-5.20.42.1-sources.jar: zio/aws/databasemigration/model/StartReplicationTaskAssessmentRunResponse.scala <==
package zio.aws.databasemigration.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class StartReplicationTaskAssessmentRunResponse(
    replicationTaskAssessmentRun: Optional[
      zio.aws.databasemigration.model.ReplicationTaskAssessmentRun
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.StartReplicationTaskAssessmentRunResponse = {
    import StartReplicationTaskAssessmentRunResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.StartReplicationTaskAssessmentRunResponse
      .builder()
      .optionallyWith(
        replicationTaskAssessmentRun.map(value => value.buildAwsValue())
      )(_.replicationTaskAssessmentRun)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.StartReplicationTaskAssessmentRunResponse.ReadOnly =
    zio.aws.databasemigration.model.StartReplicationTaskAssessmentRunResponse
      .wrap(buildAwsValue())
}
object StartReplicationTaskAssessmentRunResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.StartReplicationTaskAssessmentRunResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.databasemigration.model.StartReplicationTaskAssessmentRunResponse =
      zio.aws.databasemigration.model.StartReplicationTaskAssessmentRunResponse(
        replicationTaskAssessmentRun.map(value => value.asEditable)
      )
    def replicationTaskAssessmentRun: Optional[
      zio.aws.databasemigration.model.ReplicationTaskAssessmentRun.ReadOnly
    ]
    def getReplicationTaskAssessmentRun: ZIO[
      Any,
      AwsError,
      zio.aws.databasemigration.model.ReplicationTaskAssessmentRun.ReadOnly
    ] = AwsError.unwrapOptionField(
      "replicationTaskAssessmentRun",
      replicationTaskAssessmentRun
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.StartReplicationTaskAssessmentRunResponse
  ) extends zio.aws.databasemigration.model.StartReplicationTaskAssessmentRunResponse.ReadOnly {
    override val replicationTaskAssessmentRun: Optional[
      zio.aws.databasemigration.model.ReplicationTaskAssessmentRun.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.replicationTaskAssessmentRun())
      .map(value =>
        zio.aws.databasemigration.model.ReplicationTaskAssessmentRun.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.StartReplicationTaskAssessmentRunResponse
  ): zio.aws.databasemigration.model.StartReplicationTaskAssessmentRunResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-databasemigration_2.13-5.17.151.2-sources.jar: zio/aws/databasemigration/model/StartReplicationTaskAssessmentRunResponse.scala <==
package zio.aws.databasemigration.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class StartReplicationTaskAssessmentRunResponse(
    replicationTaskAssessmentRun: Option[
      zio.aws.databasemigration.model.ReplicationTaskAssessmentRun
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.StartReplicationTaskAssessmentRunResponse = {
    import StartReplicationTaskAssessmentRunResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.StartReplicationTaskAssessmentRunResponse
      .builder()
      .optionallyWith(
        replicationTaskAssessmentRun.map(value => value.buildAwsValue())
      )(_.replicationTaskAssessmentRun)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.StartReplicationTaskAssessmentRunResponse.ReadOnly =
    zio.aws.databasemigration.model.StartReplicationTaskAssessmentRunResponse
      .wrap(buildAwsValue())
}
object StartReplicationTaskAssessmentRunResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.StartReplicationTaskAssessmentRunResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.databasemigration.model.StartReplicationTaskAssessmentRunResponse =
      zio.aws.databasemigration.model.StartReplicationTaskAssessmentRunResponse(
        replicationTaskAssessmentRun.map(value => value.asEditable)
      )
    def replicationTaskAssessmentRun: Option[
      zio.aws.databasemigration.model.ReplicationTaskAssessmentRun.ReadOnly
    ]
    def getReplicationTaskAssessmentRun: ZIO[
      Any,
      AwsError,
      zio.aws.databasemigration.model.ReplicationTaskAssessmentRun.ReadOnly
    ] = AwsError.unwrapOptionField(
      "replicationTaskAssessmentRun",
      replicationTaskAssessmentRun
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.StartReplicationTaskAssessmentRunResponse
  ) extends zio.aws.databasemigration.model.StartReplicationTaskAssessmentRunResponse.ReadOnly {
    override val replicationTaskAssessmentRun: Option[
      zio.aws.databasemigration.model.ReplicationTaskAssessmentRun.ReadOnly
    ] = scala
      .Option(impl.replicationTaskAssessmentRun())
      .map(value =>
        zio.aws.databasemigration.model.ReplicationTaskAssessmentRun.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.StartReplicationTaskAssessmentRunResponse
  ): zio.aws.databasemigration.model.StartReplicationTaskAssessmentRunResponse.ReadOnly =
    new Wrapper(impl)
}
